==> Brq_1.0.tar.gz: Brq/man/Body.Rd <==
\name{Body}
\alias{Body}
\docType{data}
\title{Exploring Relationships in Body Dimensions}
\description{


This dataset contains 21 body dimension measurements as well as age, 
weight, height, and gender on 507 individuals. The 247 men and 260 
women were primarily individuals in their twenties and thirties, with a 
scattering of older men and women, all exercising several hours a week.


Source: 


Measurements were initially taken by Grete 
Heinz and Louis J. Peterson - at San Jose State University and at the 
U.S. Naval Postgraduate School in Monterey, California. Later, 
measurements were taken at dozens of California health and fitness 
clubs by technicians under the supervision of one of these authors.


}
\format{The data frame has the following components: 

\itemize{
 \item{BiacSk}:  Biacromial diameter (cm)
 \item{BiilSk}:  Biiliac diameter, or "pelvic breadth" (cm)
 \item{BitrSk}:  Bitrochanteric diameter (cm)
 \item{CheDeSk}:  Chest depth between spine and sternum at nipple level, 
            mid-expiration (cm)
 \item{CheDiSk}:    Chest diameter at nipple level, mid-expiration (cm)
 \item{ElbowSk}:  Elbow diameter, sum of two elbows (cm)
 \item{WristSk}: Wrist diameter, sum of two wrists (cm)
 \item{KneeSk}: Knee diameter, sum of two knees (cm)
 \item{AnkleSk}: Ankle diameter, sum of two ankles (cm)
 \item{ShoulGi}: Shoulder girth over deltoid muscles (cm)
 \item{ChestGi}: Chest girth, nipple line in males and just above breast 
            tissue in females, mid-expiration (cm)
 \item{WaistGi}: Waist girth, narrowest part of torso below the rib cage, 
            average of contracted and relaxed position (cm)
 \item{NavelGi}: Navel (or "Abdominal") girth at umbilicus and iliac crest, 
            iliac crest as a landmark (cm)
 \item{HipGi}: Hip girth at level of bitrochanteric diameter (cm)
 \item{ThighGi}: Thigh girth below gluteal fold, average of right and left 
            girths (cm)
 \item{BicepGi}: Bicep girth, flexed, average of right and left girths (cm)
 \item{ForeaGi}: Forearm girth, extended, palm up, average of right and 
            left girths (cm)
 \item{KneeGi}: Knee girth over patella, slightly flexed position, average 
            of right and left girths (cm)
 \item{CalfGi}: Calf maximum girth, average of right and left girths (cm)
 \item{AnkleGi}: Ankle minimum girth, average of right and left girths
 (cm)
 \item{WristGi}: Wrist minimum girth, average of right and left girths (cm)

 \item{Age}:  (years)
 \item{Weight}:  (kg)
 \item{Height}:  (cm)
 \item{Gender}: (1 - male, 0 - female)
 
}}
\usage{data(Body)}



\source{
Heinz, G., Peterson, L.J., Johnson, R.W. and Kerk, C.J. (2003),
``Exploring Relationships in Body Dimensions'',
\emph{Journal of Statistics Education }, 11.

}
\references{

The information on this page has been taken from the web site 
\url{http://www.amstat.org/publications/jse/datasets/body.txt}.
The dataset is download from 
\url{http://www.amstat.org/publications/jse/datasets/body.dat.txt}
}
\keyword{datasets}

==> Brq_2.3.tar.gz: Brq/man/Body.Rd <==
\name{Body}
\alias{Body}
\docType{data}
\title{Exploring Relationships in Body Dimensions}
\description{


This dataset contains 21 body dimension measurements as well as age, 
weight, height, and gender on 507 individuals. The 247 men and 260 
women were primarily individuals in their twenties and thirties, with a 
scattering of older men and women, all exercising several hours a week.


Source: 


Measurements were initially taken by Grete 
Heinz and Louis J. Peterson - at San Jose State University and at the 
U.S. Naval Postgraduate School in Monterey, California. Later, 
measurements were taken at dozens of California health and fitness 
clubs by technicians under the supervision of one of these authors.


}
\format{The data frame has the following components: 

\itemize{
 \item{BiacSk}:  Biacromial diameter (cm)
 \item{BiilSk}:  Biiliac diameter, or "pelvic breadth" (cm)
 \item{BitrSk}:  Bitrochanteric diameter (cm)
 \item{CheDeSk}:  Chest depth between spine and sternum at nipple level, 
            mid-expiration (cm)
 \item{CheDiSk}:    Chest diameter at nipple level, mid-expiration (cm)
 \item{ElbowSk}:  Elbow diameter, sum of two elbows (cm)
 \item{WristSk}: Wrist diameter, sum of two wrists (cm)
 \item{KneeSk}: Knee diameter, sum of two knees (cm)
 \item{AnkleSk}: Ankle diameter, sum of two ankles (cm)
 \item{ShoulGi}: Shoulder girth over deltoid muscles (cm)
 \item{ChestGi}: Chest girth, nipple line in males and just above breast 
            tissue in females, mid-expiration (cm)
 \item{WaistGi}: Waist girth, narrowest part of torso below the rib cage, 
            average of contracted and relaxed position (cm)
 \item{NavelGi}: Navel (or "Abdominal") girth at umbilicus and iliac crest, 
            iliac crest as a landmark (cm)
 \item{HipGi}: Hip girth at level of bitrochanteric diameter (cm)
 \item{ThighGi}: Thigh girth below gluteal fold, average of right and left 
            girths (cm)
 \item{BicepGi}: Bicep girth, flexed, average of right and left girths (cm)
 \item{ForeaGi}: Forearm girth, extended, palm up, average of right and 
            left girths (cm)
 \item{KneeGi}: Knee girth over patella, slightly flexed position, average 
            of right and left girths (cm)
 \item{CalfGi}: Calf maximum girth, average of right and left girths (cm)
 \item{AnkleGi}: Ankle minimum girth, average of right and left girths
 (cm)
 \item{WristGi}: Wrist minimum girth, average of right and left girths (cm)

 \item{Age}:  (years)
 \item{Weight}:  (kg)
 \item{Height}:  (cm)
 \item{Gender}: (1 - male, 0 - female)
 
}}
\usage{data(Body)}



\source{
Heinz, G., Peterson, L.J., Johnson, R.W. and Kerk, C.J. (2003),
``Exploring Relationships in Body Dimensions'',
\emph{Journal of Statistics Education }, 11.

}
%\references{

%The information on this page has been taken from the web site 
%\url{http://www.amstat.org/publications/jse/datasets/body.txt}.
%The dataset is download from 
%\url{http://www.amstat.org/publications/jse/datasets/body.dat.txt}
%}
\keyword{datasets}
